@@ -12,8 +12,9 @@ class NullTrueFieldBase(models.SubfieldBase):
         return value == True
 
 
-class NullTrueField(models.NullBooleanField):   
-    __metaclass__ = NullTrueFieldBase 
+class NullTrueField(models.NullBooleanField):
+    __metaclass__ = NullTrueFieldBase
+
     def to_python(self, value):
         if value is True:
             return value
@@ -23,7 +24,7 @@ class NullTrueField(models.NullBooleanField):
         if value is None or value is False:
             return None
         return True
-    
+
     def formfield(self, **kwargs):
         defaults = {
             'form_class': forms.NullTrueField,
@@ -32,7 +33,7 @@ class NullTrueField(models.NullBooleanField):
             'help_text': self.help_text}
         defaults.update(kwargs)
         return super(NullTrueField, self).formfield(**defaults)
-    
+
 
 # ISO 3166-1 country names and codes adapted from http://opencountrycodes.appspot.com/python/
 CONTINENTS = [
@@ -45,258 +46,257 @@ CONTINENTS = [
     (u'south-america', _(u'South America')),
 ]
 
-
 COUNTRIES = (
-    ('GB', _('United Kingdom')), 
-    ('AF', _('Afghanistan')), 
-    ('AX', _('Aland Islands')), 
-    ('AL', _('Albania')), 
-    ('DZ', _('Algeria')), 
-    ('AS', _('American Samoa')), 
-    ('AD', _('Andorra')), 
-    ('AO', _('Angola')), 
-    ('AI', _('Anguilla')), 
-    ('AQ', _('Antarctica')), 
-    ('AG', _('Antigua and Barbuda')), 
-    ('AR', _('Argentina')), 
-    ('AM', _('Armenia')), 
-    ('AW', _('Aruba')), 
-    ('AU', _('Australia')), 
-    ('AT', _('Austria')), 
-    ('AZ', _('Azerbaijan')), 
-    ('BS', _('Bahamas')), 
-    ('BH', _('Bahrain')), 
-    ('BD', _('Bangladesh')), 
-    ('BB', _('Barbados')), 
-    ('BY', _('Belarus')), 
-    ('BE', _('Belgium')), 
-    ('BZ', _('Belize')), 
-    ('BJ', _('Benin')), 
-    ('BM', _('Bermuda')), 
-    ('BT', _('Bhutan')), 
-    ('BO', _('Bolivia')), 
-    ('BA', _('Bosnia and Herzegovina')), 
-    ('BW', _('Botswana')), 
-    ('BV', _('Bouvet Island')), 
-    ('BR', _('Brazil')), 
-    ('IO', _('British Indian Ocean Territory')), 
-    ('BN', _('Brunei Darussalam')), 
-    ('BG', _('Bulgaria')), 
-    ('BF', _('Burkina Faso')), 
-    ('BI', _('Burundi')), 
-    ('KH', _('Cambodia')), 
-    ('CM', _('Cameroon')), 
-    ('CA', _('Canada')), 
-    ('CV', _('Cape Verde')), 
-    ('KY', _('Cayman Islands')), 
-    ('CF', _('Central African Republic')), 
-    ('TD', _('Chad')), 
-    ('CL', _('Chile')), 
-    ('CN', _('China')), 
-    ('CX', _('Christmas Island')), 
-    ('CC', _('Cocos (Keeling) Islands')), 
-    ('CO', _('Colombia')), 
-    ('KM', _('Comoros')), 
-    ('CG', _('Congo')), 
-    ('CD', _('Congo, The Democratic Republic of the')), 
-    ('CK', _('Cook Islands')), 
-    ('CR', _('Costa Rica')), 
-    ('CI', _('Cote d\'Ivoire')), 
-    ('HR', _('Croatia')), 
-    ('CU', _('Cuba')), 
-    ('CY', _('Cyprus')), 
-    ('CZ', _('Czech Republic')), 
-    ('DK', _('Denmark')), 
-    ('DJ', _('Djibouti')), 
-    ('DM', _('Dominica')), 
-    ('DO', _('Dominican Republic')), 
-    ('EC', _('Ecuador')), 
-    ('EG', _('Egypt')), 
-    ('SV', _('El Salvador')), 
-    ('GQ', _('Equatorial Guinea')), 
-    ('ER', _('Eritrea')), 
-    ('EE', _('Estonia')), 
-    ('ET', _('Ethiopia')), 
-    ('FK', _('Falkland Islands (Malvinas)')), 
-    ('FO', _('Faroe Islands')), 
-    ('FJ', _('Fiji')), 
-    ('FI', _('Finland')), 
-    ('FR', _('France')), 
-    ('GF', _('French Guiana')), 
-    ('PF', _('French Polynesia')), 
-    ('TF', _('French Southern Territories')), 
-    ('GA', _('Gabon')), 
-    ('GM', _('Gambia')), 
-    ('GE', _('Georgia')), 
-    ('DE', _('Germany')), 
-    ('GH', _('Ghana')), 
-    ('GI', _('Gibraltar')), 
-    ('GR', _('Greece')), 
-    ('GL', _('Greenland')), 
-    ('GD', _('Grenada')), 
-    ('GP', _('Guadeloupe')), 
-    ('GU', _('Guam')), 
-    ('GT', _('Guatemala')), 
-    ('GG', _('Guernsey')), 
-    ('GN', _('Guinea')), 
-    ('GW', _('Guinea-Bissau')), 
-    ('GY', _('Guyana')), 
-    ('HT', _('Haiti')), 
-    ('HM', _('Heard Island and McDonald Islands')), 
-    ('VA', _('Holy See (Vatican City State)')), 
-    ('HN', _('Honduras')), 
-    ('HK', _('Hong Kong')), 
-    ('HU', _('Hungary')), 
-    ('IS', _('Iceland')), 
-    ('IN', _('India')), 
-    ('ID', _('Indonesia')), 
-    ('IR', _('Iran, Islamic Republic of')), 
-    ('IQ', _('Iraq')), 
-    ('IE', _('Ireland')), 
-    ('IM', _('Isle of Man')), 
-    ('IL', _('Israel')), 
-    ('IT', _('Italy')), 
-    ('JM', _('Jamaica')), 
-    ('JP', _('Japan')), 
-    ('JE', _('Jersey')), 
-    ('JO', _('Jordan')), 
-    ('KZ', _('Kazakhstan')), 
-    ('KE', _('Kenya')), 
-    ('KI', _('Kiribati')), 
-    ('KP', _('Korea, Democratic People\'s Republic of')), 
-    ('KR', _('Korea, Republic of')), 
-    ('KW', _('Kuwait')), 
-    ('KG', _('Kyrgyzstan')), 
-    ('LA', _('Lao People\'s Democratic Republic')), 
-    ('LV', _('Latvia')), 
-    ('LB', _('Lebanon')), 
-    ('LS', _('Lesotho')), 
-    ('LR', _('Liberia')), 
-    ('LY', _('Libyan Arab Jamahiriya')), 
-    ('LI', _('Liechtenstein')), 
-    ('LT', _('Lithuania')), 
-    ('LU', _('Luxembourg')), 
-    ('MO', _('Macao')), 
-    ('MK', _('Macedonia, The Former Yugoslav Republic of')), 
-    ('MG', _('Madagascar')), 
-    ('MW', _('Malawi')), 
-    ('MY', _('Malaysia')), 
-    ('MV', _('Maldives')), 
-    ('ML', _('Mali')), 
-    ('MT', _('Malta')), 
-    ('MH', _('Marshall Islands')), 
-    ('MQ', _('Martinique')), 
-    ('MR', _('Mauritania')), 
-    ('MU', _('Mauritius')), 
-    ('YT', _('Mayotte')), 
-    ('MX', _('Mexico')), 
-    ('FM', _('Micronesia, Federated States of')), 
-    ('MD', _('Moldova')), 
-    ('MC', _('Monaco')), 
-    ('MN', _('Mongolia')), 
-    ('ME', _('Montenegro')), 
-    ('MS', _('Montserrat')), 
-    ('MA', _('Morocco')), 
-    ('MZ', _('Mozambique')), 
-    ('MM', _('Myanmar')), 
-    ('NA', _('Namibia')), 
-    ('NR', _('Nauru')), 
-    ('NP', _('Nepal')), 
-    ('NL', _('Netherlands')), 
-    ('AN', _('Netherlands Antilles')), 
-    ('NC', _('New Caledonia')), 
-    ('NZ', _('New Zealand')), 
-    ('NI', _('Nicaragua')), 
-    ('NE', _('Niger')), 
-    ('NG', _('Nigeria')), 
-    ('NU', _('Niue')), 
-    ('NF', _('Norfolk Island')), 
-    ('MP', _('Northern Mariana Islands')), 
-    ('NO', _('Norway')), 
-    ('OM', _('Oman')), 
-    ('PK', _('Pakistan')), 
-    ('PW', _('Palau')), 
-    ('PS', _('Palestinian Territory, Occupied')), 
-    ('PA', _('Panama')), 
-    ('PG', _('Papua New Guinea')), 
-    ('PY', _('Paraguay')), 
-    ('PE', _('Peru')), 
-    ('PH', _('Philippines')), 
-    ('PN', _('Pitcairn')), 
-    ('PL', _('Poland')), 
-    ('PT', _('Portugal')), 
-    ('PR', _('Puerto Rico')), 
-    ('QA', _('Qatar')), 
-    ('RE', _('Reunion')), 
-    ('RO', _('Romania')), 
-    ('RU', _('Russian Federation')), 
-    ('RW', _('Rwanda')), 
-    ('BL', _('Saint Barthelemy')), 
-    ('SH', _('Saint Helena')), 
-    ('KN', _('Saint Kitts and Nevis')), 
-    ('LC', _('Saint Lucia')), 
-    ('MF', _('Saint Martin')), 
-    ('PM', _('Saint Pierre and Miquelon')), 
-    ('VC', _('Saint Vincent and the Grenadines')), 
-    ('WS', _('Samoa')), 
-    ('SM', _('San Marino')), 
-    ('ST', _('Sao Tome and Principe')), 
-    ('SA', _('Saudi Arabia')), 
-    ('SN', _('Senegal')), 
-    ('RS', _('Serbia')), 
-    ('SC', _('Seychelles')), 
-    ('SL', _('Sierra Leone')), 
-    ('SG', _('Singapore')), 
-    ('SK', _('Slovakia')), 
-    ('SI', _('Slovenia')), 
-    ('SB', _('Solomon Islands')), 
-    ('SO', _('Somalia')), 
-    ('ZA', _('South Africa')), 
-    ('GS', _('South Georgia and the South Sandwich Islands')), 
-    ('ES', _('Spain')), 
-    ('LK', _('Sri Lanka')), 
-    ('SD', _('Sudan')), 
-    ('SR', _('Suriname')), 
-    ('SJ', _('Svalbard and Jan Mayen')), 
-    ('SZ', _('Swaziland')), 
-    ('SE', _('Sweden')), 
-    ('CH', _('Switzerland')), 
-    ('SY', _('Syrian Arab Republic')), 
-    ('TW', _('Taiwan, Province of China')), 
-    ('TJ', _('Tajikistan')), 
-    ('TZ', _('Tanzania, United Republic of')), 
-    ('TH', _('Thailand')), 
-    ('TL', _('Timor-Leste')), 
-    ('TG', _('Togo')), 
-    ('TK', _('Tokelau')), 
-    ('TO', _('Tonga')), 
-    ('TT', _('Trinidad and Tobago')), 
-    ('TN', _('Tunisia')), 
-    ('TR', _('Turkey')), 
-    ('TM', _('Turkmenistan')), 
-    ('TC', _('Turks and Caicos Islands')), 
-    ('TV', _('Tuvalu')), 
-    ('UG', _('Uganda')), 
-    ('UA', _('Ukraine')), 
-    ('AE', _('United Arab Emirates')), 
-    ('US', _('United States')), 
-    ('UM', _('United States Minor Outlying Islands')), 
-    ('UY', _('Uruguay')), 
-    ('UZ', _('Uzbekistan')), 
-    ('VU', _('Vanuatu')), 
-    ('VE', _('Venezuela')), 
-    ('VN', _('Viet Nam')), 
-    ('VG', _('Virgin Islands, British')), 
-    ('VI', _('Virgin Islands, U.S.')), 
-    ('WF', _('Wallis and Futuna')), 
-    ('EH', _('Western Sahara')), 
-    ('YE', _('Yemen')), 
-    ('ZM', _('Zambia')), 
-    ('ZW', _('Zimbabwe')), 
+    ('GB', _('United Kingdom')),
+    ('AF', _('Afghanistan')),
+    ('AX', _('Aland Islands')),
+    ('AL', _('Albania')),
+    ('DZ', _('Algeria')),
+    ('AS', _('American Samoa')),
+    ('AD', _('Andorra')),
+    ('AO', _('Angola')),
+    ('AI', _('Anguilla')),
+    ('AQ', _('Antarctica')),
+    ('AG', _('Antigua and Barbuda')),
+    ('AR', _('Argentina')),
+    ('AM', _('Armenia')),
+    ('AW', _('Aruba')),
+    ('AU', _('Australia')),
+    ('AT', _('Austria')),
+    ('AZ', _('Azerbaijan')),
+    ('BS', _('Bahamas')),
+    ('BH', _('Bahrain')),
+    ('BD', _('Bangladesh')),
+    ('BB', _('Barbados')),
+    ('BY', _('Belarus')),
+    ('BE', _('Belgium')),
+    ('BZ', _('Belize')),
+    ('BJ', _('Benin')),
+    ('BM', _('Bermuda')),
+    ('BT', _('Bhutan')),
+    ('BO', _('Bolivia')),
+    ('BA', _('Bosnia and Herzegovina')),
+    ('BW', _('Botswana')),
+    ('BV', _('Bouvet Island')),
+    ('BR', _('Brazil')),
+    ('IO', _('British Indian Ocean Territory')),
+    ('BN', _('Brunei Darussalam')),
+    ('BG', _('Bulgaria')),
+    ('BF', _('Burkina Faso')),
+    ('BI', _('Burundi')),
+    ('KH', _('Cambodia')),
+    ('CM', _('Cameroon')),
+    ('CA', _('Canada')),
+    ('CV', _('Cape Verde')),
+    ('KY', _('Cayman Islands')),
+    ('CF', _('Central African Republic')),
+    ('TD', _('Chad')),
+    ('CL', _('Chile')),
+    ('CN', _('China')),
+    ('CX', _('Christmas Island')),
+    ('CC', _('Cocos (Keeling) Islands')),
+    ('CO', _('Colombia')),
+    ('KM', _('Comoros')),
+    ('CG', _('Congo')),
+    ('CD', _('Congo, The Democratic Republic of the')),
+    ('CK', _('Cook Islands')),
+    ('CR', _('Costa Rica')),
+    ('CI', _('Cote d\'Ivoire')),
+    ('HR', _('Croatia')),
+    ('CU', _('Cuba')),
+    ('CY', _('Cyprus')),
+    ('CZ', _('Czech Republic')),
+    ('DK', _('Denmark')),
+    ('DJ', _('Djibouti')),
+    ('DM', _('Dominica')),
+    ('DO', _('Dominican Republic')),
+    ('EC', _('Ecuador')),
+    ('EG', _('Egypt')),
+    ('SV', _('El Salvador')),
+    ('GQ', _('Equatorial Guinea')),
+    ('ER', _('Eritrea')),
+    ('EE', _('Estonia')),
+    ('ET', _('Ethiopia')),
+    ('FK', _('Falkland Islands (Malvinas)')),
+    ('FO', _('Faroe Islands')),
+    ('FJ', _('Fiji')),
+    ('FI', _('Finland')),
+    ('FR', _('France')),
+    ('GF', _('French Guiana')),
+    ('PF', _('French Polynesia')),
+    ('TF', _('French Southern Territories')),
+    ('GA', _('Gabon')),
+    ('GM', _('Gambia')),
+    ('GE', _('Georgia')),
+    ('DE', _('Germany')),
+    ('GH', _('Ghana')),
+    ('GI', _('Gibraltar')),
+    ('GR', _('Greece')),
+    ('GL', _('Greenland')),
+    ('GD', _('Grenada')),
+    ('GP', _('Guadeloupe')),
+    ('GU', _('Guam')),
+    ('GT', _('Guatemala')),
+    ('GG', _('Guernsey')),
+    ('GN', _('Guinea')),
+    ('GW', _('Guinea-Bissau')),
+    ('GY', _('Guyana')),
+    ('HT', _('Haiti')),
+    ('HM', _('Heard Island and McDonald Islands')),
+    ('VA', _('Holy See (Vatican City State)')),
+    ('HN', _('Honduras')),
+    ('HK', _('Hong Kong')),
+    ('HU', _('Hungary')),
+    ('IS', _('Iceland')),
+    ('IN', _('India')),
+    ('ID', _('Indonesia')),
+    ('IR', _('Iran, Islamic Republic of')),
+    ('IQ', _('Iraq')),
+    ('IE', _('Ireland')),
+    ('IM', _('Isle of Man')),
+    ('IL', _('Israel')),
+    ('IT', _('Italy')),
+    ('JM', _('Jamaica')),
+    ('JP', _('Japan')),
+    ('JE', _('Jersey')),
+    ('JO', _('Jordan')),
+    ('KZ', _('Kazakhstan')),
+    ('KE', _('Kenya')),
+    ('KI', _('Kiribati')),
+    ('KP', _('Korea, Democratic People\'s Republic of')),
+    ('KR', _('Korea, Republic of')),
+    ('KW', _('Kuwait')),
+    ('KG', _('Kyrgyzstan')),
+    ('LA', _('Lao People\'s Democratic Republic')),
+    ('LV', _('Latvia')),
+    ('LB', _('Lebanon')),
+    ('LS', _('Lesotho')),
+    ('LR', _('Liberia')),
+    ('LY', _('Libyan Arab Jamahiriya')),
+    ('LI', _('Liechtenstein')),
+    ('LT', _('Lithuania')),
+    ('LU', _('Luxembourg')),
+    ('MO', _('Macao')),
+    ('MK', _('Macedonia, The Former Yugoslav Republic of')),
+    ('MG', _('Madagascar')),
+    ('MW', _('Malawi')),
+    ('MY', _('Malaysia')),
+    ('MV', _('Maldives')),
+    ('ML', _('Mali')),
+    ('MT', _('Malta')),
+    ('MH', _('Marshall Islands')),
+    ('MQ', _('Martinique')),
+    ('MR', _('Mauritania')),
+    ('MU', _('Mauritius')),
+    ('YT', _('Mayotte')),
+    ('MX', _('Mexico')),
+    ('FM', _('Micronesia, Federated States of')),
+    ('MD', _('Moldova')),
+    ('MC', _('Monaco')),
+    ('MN', _('Mongolia')),
+    ('ME', _('Montenegro')),
+    ('MS', _('Montserrat')),
+    ('MA', _('Morocco')),
+    ('MZ', _('Mozambique')),
+    ('MM', _('Myanmar')),
+    ('NA', _('Namibia')),
+    ('NR', _('Nauru')),
+    ('NP', _('Nepal')),
+    ('NL', _('Netherlands')),
+    ('AN', _('Netherlands Antilles')),
+    ('NC', _('New Caledonia')),
+    ('NZ', _('New Zealand')),
+    ('NI', _('Nicaragua')),
+    ('NE', _('Niger')),
+    ('NG', _('Nigeria')),
+    ('NU', _('Niue')),
+    ('NF', _('Norfolk Island')),
+    ('MP', _('Northern Mariana Islands')),
+    ('NO', _('Norway')),
+    ('OM', _('Oman')),
+    ('PK', _('Pakistan')),
+    ('PW', _('Palau')),
+    ('PS', _('Palestinian Territory, Occupied')),
+    ('PA', _('Panama')),
+    ('PG', _('Papua New Guinea')),
+    ('PY', _('Paraguay')),
+    ('PE', _('Peru')),
+    ('PH', _('Philippines')),
+    ('PN', _('Pitcairn')),
+    ('PL', _('Poland')),
+    ('PT', _('Portugal')),
+    ('PR', _('Puerto Rico')),
+    ('QA', _('Qatar')),
+    ('RE', _('Reunion')),
+    ('RO', _('Romania')),
+    ('RU', _('Russian Federation')),
+    ('RW', _('Rwanda')),
+    ('BL', _('Saint Barthelemy')),
+    ('SH', _('Saint Helena')),
+    ('KN', _('Saint Kitts and Nevis')),
+    ('LC', _('Saint Lucia')),
+    ('MF', _('Saint Martin')),
+    ('PM', _('Saint Pierre and Miquelon')),
+    ('VC', _('Saint Vincent and the Grenadines')),
+    ('WS', _('Samoa')),
+    ('SM', _('San Marino')),
+    ('ST', _('Sao Tome and Principe')),
+    ('SA', _('Saudi Arabia')),
+    ('SN', _('Senegal')),
+    ('RS', _('Serbia')),
+    ('SC', _('Seychelles')),
+    ('SL', _('Sierra Leone')),
+    ('SG', _('Singapore')),
+    ('SK', _('Slovakia')),
+    ('SI', _('Slovenia')),
+    ('SB', _('Solomon Islands')),
+    ('SO', _('Somalia')),
+    ('ZA', _('South Africa')),
+    ('GS', _('South Georgia and the South Sandwich Islands')),
+    ('ES', _('Spain')),
+    ('LK', _('Sri Lanka')),
+    ('SD', _('Sudan')),
+    ('SR', _('Suriname')),
+    ('SJ', _('Svalbard and Jan Mayen')),
+    ('SZ', _('Swaziland')),
+    ('SE', _('Sweden')),
+    ('CH', _('Switzerland')),
+    ('SY', _('Syrian Arab Republic')),
+    ('TW', _('Taiwan, Province of China')),
+    ('TJ', _('Tajikistan')),
+    ('TZ', _('Tanzania, United Republic of')),
+    ('TH', _('Thailand')),
+    ('TL', _('Timor-Leste')),
+    ('TG', _('Togo')),
+    ('TK', _('Tokelau')),
+    ('TO', _('Tonga')),
+    ('TT', _('Trinidad and Tobago')),
+    ('TN', _('Tunisia')),
+    ('TR', _('Turkey')),
+    ('TM', _('Turkmenistan')),
+    ('TC', _('Turks and Caicos Islands')),
+    ('TV', _('Tuvalu')),
+    ('UG', _('Uganda')),
+    ('UA', _('Ukraine')),
+    ('AE', _('United Arab Emirates')),
+    ('US', _('United States')),
+    ('UM', _('United States Minor Outlying Islands')),
+    ('UY', _('Uruguay')),
+    ('UZ', _('Uzbekistan')),
+    ('VU', _('Vanuatu')),
+    ('VE', _('Venezuela')),
+    ('VN', _('Viet Nam')),
+    ('VG', _('Virgin Islands, British')),
+    ('VI', _('Virgin Islands, U.S.')),
+    ('WF', _('Wallis and Futuna')),
+    ('EH', _('Western Sahara')),
+    ('YE', _('Yemen')),
+    ('ZM', _('Zambia')),
+    ('ZW', _('Zimbabwe')),
 )
 
 CONTINENT_COUNTRIES = (
-    (_(u'Africa'),(
+    (_(u'Africa'), (
         ('DZ', _(u'Algeria')),
         ('AO', _(u'Angola')),
         ('BJ', _(u'Benin')),
@@ -354,14 +354,14 @@ CONTINENT_COUNTRIES = (
         ('EH', _(u'Western Sahara')),
         ('ZM', _(u'Zambia')),
         ('ZW', _(u'Zimbabwe')),
-        )),
-    (_(u'Antarctica'),(
+    )),
+    (_(u'Antarctica'), (
         ('AQ', _(u'Antarctica')),
         ('BV', _(u'Bouvet Island')),
         ('TF', _(u'French Southern Territories')),
         ('HM', _(u'Heard Island and McDonald Islands')),
-        )),
-    (_(u'Asia'),(
+    )),
+    (_(u'Asia'), (
         ('AF', _(u'Afghanistan')),
         ('BH', _(u'Bahrain')),
         ('BD', _(u'Bangladesh')),
@@ -411,8 +411,8 @@ CONTINENT_COUNTRIES = (
         ('UZ', _(u'Uzbekistan')),
         ('VN', _(u'Vietnam')),
         ('YE', _(u'Yemen')),
-        )),
-    (_(u'Europe'),(
+    )),
+    (_(u'Europe'), (
         ('AX', _(u'Aland Islands')),
         ('AL', _(u'Albania')),
         ('AD', _(u'Andorra')),
@@ -468,8 +468,8 @@ CONTINENT_COUNTRIES = (
         ('UA', _(u'Ukraine')),
         ('GB', _(u'United Kingdom')),
         ('VA', _(u'Holy See (Vatican City State)')),
-        )),
-    (_(u'North America'),(
+    )),
+    (_(u'North America'), (
         ('AS', _(u'American Samoa')),
         ('AI', _(u'Anguilla')),
         ('AG', _(u'Antigua and Barbuda')),
@@ -509,8 +509,8 @@ CONTINENT_COUNTRIES = (
         ('UM', _(u'United States Minor Outlying Islands')),
         ('VG', _(u'Virgin Islands, British')),
         ('VI', _(u'Virgin Islands, U.S.')),
-        )),
-    (_(u'Oceania'),(
+    )),
+    (_(u'Oceania'), (
         ('AU', _(u'Australia')),
         ('CX', _(u'Christmas Island')),
         ('CC', _(u'Cocos (Keeling) Islands')),
@@ -537,8 +537,8 @@ CONTINENT_COUNTRIES = (
         ('TV', _(u'Tuvalu')),
         ('VU', _(u'Vanuatu')),
         ('WF', _(u'Wallis and Futuna')),
-        )),
-    (_(u'South America'),(
+    )),
+    (_(u'South America'), (
         ('AR', _(u'Argentina')),
         ('BO', _(u'Bolivia')),
         ('BR', _(u'Brazil')),
@@ -555,7 +555,7 @@ CONTINENT_COUNTRIES = (
         ('SR', _(u'Suriname')),
         ('UY', _(u'Uruguay')),
         ('VE', _(u'Venezuela')),
-        )
+    )
     ),
 )
 
@@ -564,6 +564,7 @@ class CountryField(models.CharField):
     """
     Is a CharField with the complete list of countries as choices.
     """
+
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 2)
         kwargs.setdefault('choices', COUNTRIES)
@@ -575,35 +576,37 @@ class CountryField(models.CharField):
         Returns internal type of this field: CharField as string
         """
         return "CharField"
-    
+
     def formfield(self, **kwargs):
         defaults = {
             'form_class': forms.NullTrueField
         }
         defaults.update(kwargs)
-        return super(CountryField, self).formfield(**defaults) 
-        
+        return super(CountryField, self).formfield(**defaults)
+
 
 class ContinentCountryField(models.CharField):
     """
     Is a CharField with the complete list of countries as choices.
     """
-    
+
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 2)
         kwargs.setdefault('choices', CONTINENT_COUNTRIES)
-        
+
         super(ContinentCountryField, self).__init__(*args, **kwargs)
 
     def get_internal_type(self):
         """
         Returns internal type of this field: CharField as string
         """
-        return "CharField"     
+        return "CharField"
+
 
-    
 try:
     from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ["^upy\.fields\.ContinentCountryField","^upy\.fields\.CountryField","^upy\.fields\.NullTrueField"])
+
+    add_introspection_rules([],
+        ["^upy\.fields\.ContinentCountryField", "^upy\.fields\.CountryField", "^upy\.fields\.NullTrueField"])
 except ImportError:
     pass
\ No newline at end of file
